@@ -1,5 +1,7 @@
-QA = function(isoscape, known, valiStation = ceiling(length(known)*0.1), 
-               valiTime = 50, mask = NULL, setSeed = TRUE, name = NULL){
+QA = function(isoscape, known, 
+              valiStation = ceiling(length(known)*0.1), 
+               valiTime = 50, by = 2, mask = NULL, 
+              setSeed = TRUE, name = NULL){
 
   #check that isoscape is valid and has defined CRS
   if (class(isoscape)[1] == "RasterStack" | 
@@ -43,6 +45,9 @@ QA = function(isoscape, known, valiStation = ceiling(length(known)*0.1),
   if(valiTime < 2){
     stop("valiTime must be an integer greater than 1")
   }
+  if(!(as.integer(by) == by) || by < 1 || by > 25){
+    stop("by must be an integer between 1 and 25")
+  }
   if(!is.null(mask)) {
     if(class(mask)[1] == "SpatialPolygonsDataFrame" || 
        class(mask)[1] == "SpatialPolygons"){
@@ -76,8 +81,12 @@ QA = function(isoscape, known, valiStation = ceiling(length(known)*0.1),
   }
 
   stationNum4model = rowLength - valiStation
-  prption_byProb = matrix(0, valiTime, 101)   
-  prption_byArea = matrix(0, valiTime, 101) 
+  xx = seq(1, 101, by)
+  if(tail(xx, 1) != 101){
+    xx = c(xx, 101)
+  }
+  prption_byProb = matrix(0, valiTime, length(xx))   
+  prption_byArea = matrix(0, valiTime, length(xx)) 
   pd_v = matrix(0, valiTime, valiStation) 
   precision = list() 
   
@@ -98,30 +107,30 @@ QA = function(isoscape, known, valiStation = ceiling(length(known)*0.1),
       pd_v[i, j] = raster::extract(pd[[j]], v[j,])
     }
 
-    xx = seq(1, 101, 1)
-
     # total area
     Tarea = length(stats::na.omit(pd[[1]][]))
 
     # spatial precision and accuracy by checking top percentage by cumulative prob.
-    precision[[i]] = matrix(0, 101, valiStation) # precision
-    for(j in xx){
-      qtl = assignR::qtlRaster(pd, threshold = (j-1)/100, 
-                                thresholdType = "prob", genplot = FALSE)
+    precision[[i]] = matrix(0, length(xx), valiStation) # precision
+    for(j in seq_along(xx)){
+      qtl = assignR::qtlRaster(pd, threshold = (xx[j]-1)/100, 
+                                thresholdType = "prob", 
+                               genplot = FALSE)
       prption_byProb[i, j] = 0
       for(k in seq_len(raster::nlayers(qtl))){
         rv = raster::extract(qtl[[k]], v[k,])
         if(!is.na(rv)){
           prption_byProb[i, j] = prption_byProb[i, j] + rv
         }
-        precision[[i]][j, k] = sum(stats::na.omit(qtl[[k]][]))/Tarea # precision
+        precision[[i]][j, k] = sum(stats::na.omit(qtl[[k]][]))/Tarea 
       }
     }
 
     # sensitivity by checking top percentage by cumulative area
-    for(n in xx){
-      qtl = assignR::qtlRaster(pd, threshold = (n-1)/100, 
-                                thresholdType = "area", genplot = FALSE)
+    for(n in seq_along(xx)){
+      qtl = assignR::qtlRaster(pd, threshold = (xx[n]-1)/100, 
+                                thresholdType = "area", 
+                               genplot = FALSE)
       prption_byArea[i, n] = 0
       for(k in seq_len(raster::nlayers(qtl))){
         rv = raster::extract(qtl[[k]], v[k,])
@@ -138,10 +147,11 @@ QA = function(isoscape, known, valiStation = ceiling(length(known)*0.1),
 
   random_prob_density=1/length(stats::na.omit(raster::getValues(isoscape[[1]])))
 
-  result = list(name, val_stations, pd_v, prption_byArea, prption_byProb, 
-                 precision, random_prob_density)
-  names(result) = c("name", "val_stations", "pd_val", "prption_byArea", 
-                    "prption_byProb", "precision", "random_prob_density")
+  result = list(name, val_stations, pd_v, prption_byArea, 
+                prption_byProb, precision, random_prob_density, by)
+  names(result) = c("name", "val_stations", "pd_val", 
+                    "prption_byArea", "prption_byProb", "precision",
+                    "random_prob_density", "by")
   class(result) = "QA"
   return(result)
 }
