@@ -5,11 +5,11 @@ data("d2h_world")
 data("knownOrig") 
 d1 = subOrigData(taxon = "Charadrius montanus")
 d2 = subOrigData(taxon = "Buteo lagopus")
-qa1 = QA(isoscape = raster::aggregate(d2h_world, 6), known = d1, 
-         valiStation = 1, valiTime = 2, mask = naMap, name = "Charadrius")
+qa1 = QA(isoscape = d2h_lrNA, known = d1, valiStation = 1, valiTime = 2, 
+         by = 25, mask = naMap, name = "Charadrius")
 plot(qa1)
-qa2 = QA(isoscape = raster::aggregate(d2h_world, 6), known = d2, 
-         valiStation = 1, valiTime = 2, mask = naMap, name = "Buteo")
+qa2 = QA(isoscape = d2h_lrNA, known = d2, valiStation = 1, valiTime = 2, 
+         by = 25, mask = naMap, name = "Buteo")
 plot(qa1, qa2)
 
 test_that("plot.QA can correctly plot the output from QA",{
